Easycart
========

Easycart is a flexible session-based shopping cart application for Django.
It provides plenty of hooks for overriding and extending the way it works.

By installing this app you get:

* Highly-customizable *BaseCart* and *BaseItem* classes to represent the user
  cart and items in it.

* A handy set of reusable components (views, urls and a context processor) for
  the most common tasks. These components are completely optional.

**Requirements**: Python 2.7+/3.4+ Django 1.8+


Resources
---------
* Docs: http://django-easycart.readthedocs.io/
* Source Code: https://github.com/nevimov/django-easycart
* Issue Tracker: https://github.com/nevimov/django-easycart/issues
